==> qtjambi-qt3drender-debuginfo-windows-x64-5.15.17.jar: sources/QtJambi3DRender/QPickLineEvent_shell.h <==
#ifndef QPICKLINEEVENT_SHELL_H
#define QPICKLINEEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DRender/qpicklineevent.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qentity.h>
#include <Qt3DRender/qpickevent.h>
#include <Qt3DRender/qviewport.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qvector3d.h>
#include <QtJambi/RegistryAPI>


class QPickLineEvent_shell : public Qt3DRender::QPickLineEvent, public QtJambiShellInterface
{
public:
    QPickLineEvent_shell();
    QPickLineEvent_shell(const QPointF& position0, const QVector3D& worldIntersection1, const QVector3D& localIntersection2, float distance3, uint edgeIndex4, uint vertex1Index5, uint vertex2Index6, Qt3DRender::QPickEvent::Buttons button7, int buttons8, int modifiers9);
    ~QPickLineEvent_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPickLineEvent_access : public Qt3DRender::QPickLineEvent
{
};

#endif // QPICKLINEEVENT_SHELL_H

==> qtjambi-qt3drender-debuginfo-windows-x64-6.6.0.jar: sources/QtJambi3DRender/QPickLineEvent_shell.h <==
#ifndef QPICKLINEEVENT_SHELL_H
#define QPICKLINEEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DRender/qpicklineevent.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qentity.h>
#include <Qt3DRender/qpickevent.h>
#include <Qt3DRender/qviewport.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qvectornd.h>
#include <QtJambi/RegistryAPI>


class QPickLineEvent_shell : public Qt3DRender::QPickLineEvent, public QtJambiShellInterface
{
public:
    QPickLineEvent_shell();
    QPickLineEvent_shell(const QPointF& position0, const QVector3D& worldIntersection1, const QVector3D& localIntersection2, float distance3, uint edgeIndex4, uint vertex1Index5, uint vertex2Index6, Qt3DRender::QPickEvent::Buttons button7, int buttons8, int modifiers9);
    ~QPickLineEvent_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPickLineEvent_access : public Qt3DRender::QPickLineEvent
{
};

#endif // QPICKLINEEVENT_SHELL_H
